__author__ = "Swas.py"
__title__ = "javascript"
__license__ = "MIT"
__copyright__ = "Copyright 2021 Swas.py"
__version__ = "1.1.0"

from .console_ import console
from .jstypes import *
from .window import *
require = __import__
